========================================
Tendril Schema Management Infrastructure
========================================

.. image:: https://img.shields.io/travis/chintal/tendril-schema.svg
        :target: https://travis-ci.org/chintal/tendril-schema

.. image:: https://img.shields.io/pypi/v/tendril-schema.svg
        :target: https://pypi.python.org/pypi/tendril-schema

* License: AGPLv3
* Documentation: http://tendril-schema.readthedocs.org


Tendril Schema Management Infrastructure

